#ifndef MSP_GRAPHICS_DISPLAY_H_
#define MSP_GRAPHICS_DISPLAY_H_

#include <list>
#include <stdexcept>
#include <string>
#include "errordialog.h"
#include "monitor.h"
#include "videomode.h"

namespace Msp {
namespace Graphics {

class Window;

class Display
{
public:
	struct Private;

private:
	std::list<Monitor> monitors;
	Monitor *primary_monitor;
	std::list<VideoMode> modes;
	Private *priv;
	ErrorDialog *err_dialog;

public:
	Display(const std::string &disp_name = std::string());
	~Display();

	const Private &get_private() const { return *priv; }

	void add_window(Window &);
	void remove_window(Window &);

	const std::list<Monitor> &get_monitors() const { return monitors; }
	const std::list<VideoMode> &get_modes() const { return modes; }
	const VideoMode &get_desktop_mode() const;
	void set_mode(const VideoMode &, bool = false);
	void restore_mode();
	const VideoMode *find_mode(const VideoMode &) const;
	const VideoMode *find_mode(unsigned, unsigned) const;

	void tick();
private:
	bool process_events();
public:
	void check_error();
};

} // namespace Graphics
} // namespace Msp

#endif
